@@ -53,6 +53,11 @@ from tensorflow.keras import layers
 from tensorflow.keras.models import Model, load_model
 ################################################################################
 from deep_autoviml.modeling.one_cycle import OneCycleScheduler
+##### Suppress all TF2 and TF1.x warnings ###################
+tf2logger = tf.get_logger()
+tf2logger.warning('Silencing TF2.x warnings')
+tf2logger.root.removeHandler(tf2logger.root.handlers)
+tf.compat.v1.logging.set_verbosity(tf.compat.v1.logging.ERROR)
 
 ################################################################################
 import os
@@ -1112,4 +1117,213 @@ def save_model_artifacts(deep_model, cat_vocab_dict, var_df, save_model_path,
             fileopen.write(pickle.dumps(var_df))
         print('    Saved pickle file in %s' %pickle_path)
     except:
-        print('Unable to save cat_vocab_dict - please save or pickle it yourself.')
\ No newline at end of file
+        print('Unable to save cat_vocab_dict - please save or pickle it yourself.')
+######################################################################################
+def get_model_defaults(keras_options, model_options, targets):
+    num_classes = model_options["num_classes"]
+    num_labels = model_options["num_labels"]
+    modeltype = model_options["modeltype"]
+    patience = check_keras_options(keras_options, "patience", 10)
+    use_bias = check_keras_options(keras_options, 'use_bias', True)
+    optimizer = check_keras_options(keras_options,'optimizer', Adam(lr=0.01, beta_1=0.9, beta_2=0.999))
+    if modeltype == 'Regression':
+        reg_loss = check_keras_options(keras_options,'loss','mae') ### you can use tf.keras.losses.Huber() instead
+        #val_metrics = [check_keras_options(keras_options,'metrics',keras.metrics.RootMeanSquaredError(name='rmse'))]
+        METRICS = [keras.metrics.RootMeanSquaredError(name='rmse'), keras.metrics.MeanAbsoluteError(name='mae')]
+        #METRICS = [keras.metrics.MeanSquaredError(name="mean_squared_error", dtype=None)]
+        #METRICS = ['mean_squared_error']
+        val_metrics = check_keras_options(keras_options,'metrics',METRICS)
+        num_predicts = 1*num_labels
+        if num_labels <= 1:
+            val_loss = check_keras_options(keras_options,'loss', reg_loss)
+            val_metric = 'rmse'
+        else:
+            val_loss = []
+            for i in range(num_labels):
+                val_loss.append(reg_loss)
+            val_metric = 'loss'
+        ####### If you change the val_metrics above, you must also change its name here ####
+        output_activation = 'linear' ### use "relu" or "softplus" if you want positive values as output
+    elif modeltype == 'Classification':
+        ##### This is for Binary Classification Problems
+        #val_loss = check_keras_options(keras_options,'loss','sparse_categorical_crossentropy')
+        #val_metrics = [check_keras_options(keras_options,'metrics','AUC')]
+        #val_metrics = check_keras_options(keras_options,'metrics','accuracy')
+        cat_loss = tf.keras.losses.SparseCategoricalCrossentropy(from_logits=True)
+        val_loss = check_keras_options(keras_options,'loss', cat_loss)
+        bal_acc = BalancedSparseCategoricalAccuracy()
+        #bal_acc = 'accuracy'
+        val_metrics = check_keras_options(keras_options,'metrics',bal_acc)
+        if num_labels <= 1:
+            num_predicts = int(num_classes*num_labels)
+        else:
+            #### This is for multi-label problems wihere number of classes will be a list
+            num_predicts = num_classes
+        output_activation = "sigmoid"
+        ####### If you change the val_metrics above, you must also change its name here ####
+        val_metric = 'balanced_sparse_categorical_accuracy'
+        #val_metric = 'accuracy'
+    else:
+        #### this is for multi-class problems ####
+        cat_loss = tf.keras.losses.SparseCategoricalCrossentropy(from_logits=True)
+        #val_loss = check_keras_options(keras_options,'loss','sparse_categorical_crossentropy')
+        #val_metrics = check_keras_options(keras_options,'metrics','accuracy')
+        if num_labels <= 1:
+            num_predicts = int(num_classes*num_labels)
+            val_loss = check_keras_options(keras_options,'loss', cat_loss)
+            bal_acc = BalancedSparseCategoricalAccuracy()
+            #bal_acc = 'accuracy'
+            val_metrics = check_keras_options(keras_options, 'metrics', bal_acc)
+        else:
+            #### This is for multi-label problems wihere number of classes will be a list
+            num_predicts = num_classes
+            val_loss = []
+            for i in range(num_labels):
+                val_loss.append(cat_loss)
+            bal_acc = BalancedSparseCategoricalAccuracy()
+            #bal_acc = 'accuracy'
+            val_metrics = check_keras_options(keras_options, 'metrics', bal_acc)
+        output_activation = 'softmax'
+        ####### If you change the val_metrics above, you must also change its name here ####
+        val_metric = 'balanced_sparse_categorical_accuracy'
+        #val_metric = 'accuracy'
+    ##############  Suggested number of neurons in each layer ##################
+    if modeltype == 'Regression':
+        val_monitor = check_keras_options(keras_options, 'monitor', 'val_'+val_metric)
+        val_mode = check_keras_options(keras_options,'mode', 'min')
+    elif modeltype == 'Classification':
+        ##### This is for Binary Classification Problems
+        if num_labels <= 1:
+            val_monitor = check_keras_options(keras_options,'monitor', 'val_'+val_metric)
+            val_mode = check_keras_options(keras_options,'mode', 'max')
+            val_metric = 'balanced_sparse_categorical_accuracy'
+        else:
+            val_metric = 'balanced_sparse_categorical_accuracy'
+            #val_metric = 'accuracy'
+            ### you cannot combine multiple metrics here unless you write a new function.
+            target_A = targets[0]
+            val_monitor = 'val_loss' ### this combines all losses and is best to minimize
+            val_mode = check_keras_options(keras_options,'mode', 'min')
+        #val_monitor = check_keras_options(keras_options,'monitor', 'val_auc')
+        #val_monitor = check_keras_options(keras_options,'monitor', 'val_accuracy')
+    else:
+        #### this is for multi-class problems
+        if num_labels <= 1:
+            val_metric = 'balanced_sparse_categorical_accuracy'
+            val_monitor = check_keras_options(keras_options,'monitor', 'val_'+val_metric)
+            val_mode = check_keras_options(keras_options, 'mode', 'max')
+        else:
+            val_metric = 'balanced_sparse_categorical_accuracy'
+            #val_metric = 'accuracy'
+            ### you cannot combine multiple metrics here unless you write a new function.
+            target_A = targets[0]
+            val_monitor = 'val_loss'
+            val_mode = check_keras_options(keras_options,'mode', 'min')
+        #val_monitor = check_keras_options(keras_options, 'monitor','val_accuracy')
+    ##############################################################################
+    keras_options["mode"] = val_mode
+    keras_options["monitor"] = val_monitor
+    keras_options["metrics"] = val_metrics
+    keras_options['loss'] = val_loss
+    keras_options["patience"] = patience
+    keras_options['use_bias'] = use_bias
+    keras_options['optimizer'] = optimizer
+    return keras_options, model_options, num_predicts, output_activation
+###############################################################################
+def get_uncompiled_model(inputs, result, output_activation,
+                    num_predicts, modeltype, cols_len, targets):
+    ### The next 3 steps are most important! Don't mess with them!
+    #model_preprocessing = Model(inputs, meta_outputs)
+    #preprocessed_inputs = model_preprocessing(inputs)
+    #result = model_body(preprocessed_inputs)
+    ##### now you can add the final layer here #########
+    multi_label_predictions = defaultdict(list)
+    if isinstance(num_predicts, int):
+        key = 'predictions'
+        if modeltype == 'Regression':
+            ### this will be just 1 in regression ####
+            if num_predicts > 1:
+                for each_label in range(num_predicts):
+                    value = layers.Dense(1, activation=output_activation,
+                            name=targets[each_label])(result)
+                    multi_label_predictions[key].append(value)
+            else:
+                value = layers.Dense(1, activation=output_activation,
+                        name=targets[0])(result)
+                multi_label_predictions[key].append(value)
+        else:
+            ### this will be number of classes in classification ###
+            value = layers.Dense(num_predicts, activation=output_activation,
+                                name=targets[0])(result)
+            multi_label_predictions[key].append(value)
+    else:
+        #### This will be for multi-label, multi-class predictions only ###
+        for each_label in range(len(num_predicts)):
+            key = 'predictions'
+            if modeltype == 'Regression':
+                ### this will be just 1 in regression ####
+                value = layers.Dense(1, activation=output_activation,
+                        name=targets[0])(result)
+            else:
+                ### this will be number of classes in classification ###
+                value = layers.Dense(num_predicts[each_label], activation=output_activation,
+                                    name=targets[each_label])(result)
+            multi_label_predictions[key].append(value)
+    outputs = multi_label_predictions[key] ### outputs will be a list of Dense layers
+    ##### Set the inputs and outputs of the model here
+    
+    uncompiled_model = Model(inputs=inputs, outputs=outputs)
+    return uncompiled_model
+
+#####################################################################################
+def get_compiled_model(inputs, meta_outputs, output_activation, num_predicts, modeltype,
+                       optimizer, val_loss, val_metrics, cols_len, targets):
+    model = get_uncompiled_model(inputs, meta_outputs, output_activation,
+                        num_predicts, modeltype, cols_len, targets)
+    
+    model.compile(
+        optimizer=optimizer,
+        loss=val_loss,
+        metrics=val_metrics,
+    )
+    return model
+###############################################################################
+class BalancedSparseCategoricalAccuracy(keras.metrics.SparseCategoricalAccuracy):
+    def __init__(self, name='balanced_sparse_categorical_accuracy', dtype=None):
+        super().__init__(name, dtype=dtype)
+
+    def update_state(self, y_true, y_pred, sample_weight=None):
+        y_flat = y_true
+        if y_true.shape.ndims == y_pred.shape.ndims:
+            y_flat = tf.squeeze(y_flat, axis=[-1])
+        y_true_int = tf.cast(y_flat, tf.int32)
+
+        cls_counts = tf.math.bincount(y_true_int)
+        cls_counts = tf.math.reciprocal_no_nan(tf.cast(cls_counts, self.dtype))
+        weight = tf.gather(cls_counts, y_true_int)
+        return super().update_state(y_true, y_pred, sample_weight=weight)
+#####################################################################################
+def save_model_architecture(model, project_name, keras_model_type, cat_vocab_dict, 
+                    model_options, chart_name="model_before"):
+    """
+    This function saves the model architecture in a PNG file in the artifacts sub-folder of project_name folder
+    """
+    if isinstance(project_name,str):
+        if project_name == '':
+            project_name = "deep_autoviml"
+    else:
+        print('Project name must be a string and helps create a folder to store model.')
+        project_name = "deep_autoviml"
+    save_model_path = model_options['save_model_path']
+    save_artifacts_path = os.path.join(save_model_path, "artifacts")
+    try:
+        plot_filename = os.path.join(save_artifacts_path,chart_name)+".png"
+        print('\nSaving model architecture...')
+        tf.keras.utils.plot_model(model = model, to_file=plot_filename, dpi=72,
+                        show_layer_names=True, rankdir="LR", show_shapes=True)
+        print('    model architecture saved in file: %s' %plot_filename)
+    except:
+        print('Model architecture not saved due to error. Continuing...')
+        plot_filename = ""
+    return plot_filename
+#########################################################################################################
